==> kubernetes-model-apps-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/apps/RollingUpdateDaemonSetFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.IntOrStringFluentImpl;
import java.lang.Boolean;

 /**
  * Generated
  */
public class RollingUpdateDaemonSetFluentImpl<A extends io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent<A>{
  public RollingUpdateDaemonSetFluentImpl() {
  }
  public RollingUpdateDaemonSetFluentImpl(io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSet instance) {
    this.withMaxSurge(instance.getMaxSurge()); 
    this.withMaxUnavailable(instance.getMaxUnavailable()); 
  }
  private io.fabric8.kubernetes.api.model.IntOrStringBuilder maxSurge;
  private io.fabric8.kubernetes.api.model.IntOrStringBuilder maxUnavailable;
  
  /**
   * This method has been deprecated, please use method buildMaxSurge instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getMaxSurge() {
    return this.maxSurge!=null?this.maxSurge.build():null;
  }
  public io.fabric8.kubernetes.api.model.IntOrString buildMaxSurge() {
    return this.maxSurge!=null?this.maxSurge.build():null;
  }
  public A withMaxSurge(io.fabric8.kubernetes.api.model.IntOrString maxSurge) {
    _visitables.get("maxSurge").remove(this.maxSurge);
    if (maxSurge!=null){ this.maxSurge= new io.fabric8.kubernetes.api.model.IntOrStringBuilder(maxSurge); _visitables.get("maxSurge").add(this.maxSurge);} return (A) this;
  }
  public java.lang.Boolean hasMaxSurge() {
    return this.maxSurge != null;
  }
  public A withNewMaxSurge(java.lang.Integer intVal) {
    return (A)withMaxSurge(new IntOrString(intVal));
  }
  public A withNewMaxSurge(java.lang.String strVal) {
    return (A)withMaxSurge(new IntOrString(strVal));
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxSurgeNested<A> withNewMaxSurge() {
    return new io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluentImpl.MaxSurgeNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxSurgeNested<A> withNewMaxSurgeLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return new io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluentImpl.MaxSurgeNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxSurgeNested<A> editMaxSurge() {
    return withNewMaxSurgeLike(getMaxSurge());
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxSurgeNested<A> editOrNewMaxSurge() {
    return withNewMaxSurgeLike(getMaxSurge() != null ? getMaxSurge(): new io.fabric8.kubernetes.api.model.IntOrStringBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxSurgeNested<A> editOrNewMaxSurgeLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return withNewMaxSurgeLike(getMaxSurge() != null ? getMaxSurge(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getMaxUnavailable() {
    return this.maxUnavailable!=null?this.maxUnavailable.build():null;
  }
  public io.fabric8.kubernetes.api.model.IntOrString buildMaxUnavailable() {
    return this.maxUnavailable!=null?this.maxUnavailable.build():null;
  }
  public A withMaxUnavailable(io.fabric8.kubernetes.api.model.IntOrString maxUnavailable) {
    _visitables.get("maxUnavailable").remove(this.maxUnavailable);
    if (maxUnavailable!=null){ this.maxUnavailable= new io.fabric8.kubernetes.api.model.IntOrStringBuilder(maxUnavailable); _visitables.get("maxUnavailable").add(this.maxUnavailable);} return (A) this;
  }
  public java.lang.Boolean hasMaxUnavailable() {
    return this.maxUnavailable != null;
  }
  public A withNewMaxUnavailable(java.lang.Integer intVal) {
    return (A)withMaxUnavailable(new IntOrString(intVal));
  }
  public A withNewMaxUnavailable(java.lang.String strVal) {
    return (A)withMaxUnavailable(new IntOrString(strVal));
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxUnavailableNested<A> withNewMaxUnavailable() {
    return new io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluentImpl.MaxUnavailableNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return new io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluentImpl.MaxUnavailableNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxUnavailableNested<A> editMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable());
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): new io.fabric8.kubernetes.api.model.IntOrStringBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RollingUpdateDaemonSetFluentImpl that = (RollingUpdateDaemonSetFluentImpl) o;
    if (maxSurge != null ? !maxSurge.equals(that.maxSurge) :that.maxSurge != null) return false;
    if (maxUnavailable != null ? !maxUnavailable.equals(that.maxUnavailable) :that.maxUnavailable != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxSurge,  maxUnavailable,  super.hashCode());
  }
  public class MaxSurgeNestedImpl<N> extends io.fabric8.kubernetes.api.model.IntOrStringFluentImpl<io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxSurgeNested<N>> implements io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxSurgeNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MaxSurgeNestedImpl(io.fabric8.kubernetes.api.model.IntOrString item) {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this, item);
    }
    MaxSurgeNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this);
    }
    io.fabric8.kubernetes.api.model.IntOrStringBuilder builder;
    public N and() {
      return (N) RollingUpdateDaemonSetFluentImpl.this.withMaxSurge(builder.build());
    }
    public N endMaxSurge() {
      return and();
    }
    
  }
  public class MaxUnavailableNestedImpl<N> extends io.fabric8.kubernetes.api.model.IntOrStringFluentImpl<io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxUnavailableNested<N>> implements io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxUnavailableNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MaxUnavailableNestedImpl(io.fabric8.kubernetes.api.model.IntOrString item) {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this, item);
    }
    MaxUnavailableNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this);
    }
    io.fabric8.kubernetes.api.model.IntOrStringBuilder builder;
    public N and() {
      return (N) RollingUpdateDaemonSetFluentImpl.this.withMaxUnavailable(builder.build());
    }
    public N endMaxUnavailable() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-apps-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/apps/RollingUpdateDaemonSetFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.IntOrStringFluentImpl;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class RollingUpdateDaemonSetFluentImpl<A extends io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent<A>{
  public RollingUpdateDaemonSetFluentImpl() {
  }
  public RollingUpdateDaemonSetFluentImpl(io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSet instance) {
    this.withMaxSurge(instance.getMaxSurge()); 
    this.withMaxUnavailable(instance.getMaxUnavailable()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.IntOrStringBuilder maxSurge;
  private io.fabric8.kubernetes.api.model.IntOrStringBuilder maxUnavailable;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMaxSurge instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getMaxSurge() {
    return this.maxSurge!=null?this.maxSurge.build():null;
  }
  public io.fabric8.kubernetes.api.model.IntOrString buildMaxSurge() {
    return this.maxSurge!=null?this.maxSurge.build():null;
  }
  public A withMaxSurge(io.fabric8.kubernetes.api.model.IntOrString maxSurge) {
    _visitables.get("maxSurge").remove(this.maxSurge);
    if (maxSurge!=null){ this.maxSurge= new io.fabric8.kubernetes.api.model.IntOrStringBuilder(maxSurge); _visitables.get("maxSurge").add(this.maxSurge);} return (A) this;
  }
  public java.lang.Boolean hasMaxSurge() {
    return this.maxSurge != null;
  }
  public A withNewMaxSurge(java.lang.Integer intVal) {
    return (A)withMaxSurge(new IntOrString(intVal));
  }
  public A withNewMaxSurge(java.lang.String strVal) {
    return (A)withMaxSurge(new IntOrString(strVal));
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxSurgeNested<A> withNewMaxSurge() {
    return new io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluentImpl.MaxSurgeNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxSurgeNested<A> withNewMaxSurgeLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return new io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluentImpl.MaxSurgeNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxSurgeNested<A> editMaxSurge() {
    return withNewMaxSurgeLike(getMaxSurge());
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxSurgeNested<A> editOrNewMaxSurge() {
    return withNewMaxSurgeLike(getMaxSurge() != null ? getMaxSurge(): new io.fabric8.kubernetes.api.model.IntOrStringBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxSurgeNested<A> editOrNewMaxSurgeLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return withNewMaxSurgeLike(getMaxSurge() != null ? getMaxSurge(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getMaxUnavailable() {
    return this.maxUnavailable!=null?this.maxUnavailable.build():null;
  }
  public io.fabric8.kubernetes.api.model.IntOrString buildMaxUnavailable() {
    return this.maxUnavailable!=null?this.maxUnavailable.build():null;
  }
  public A withMaxUnavailable(io.fabric8.kubernetes.api.model.IntOrString maxUnavailable) {
    _visitables.get("maxUnavailable").remove(this.maxUnavailable);
    if (maxUnavailable!=null){ this.maxUnavailable= new io.fabric8.kubernetes.api.model.IntOrStringBuilder(maxUnavailable); _visitables.get("maxUnavailable").add(this.maxUnavailable);} return (A) this;
  }
  public java.lang.Boolean hasMaxUnavailable() {
    return this.maxUnavailable != null;
  }
  public A withNewMaxUnavailable(java.lang.Integer intVal) {
    return (A)withMaxUnavailable(new IntOrString(intVal));
  }
  public A withNewMaxUnavailable(java.lang.String strVal) {
    return (A)withMaxUnavailable(new IntOrString(strVal));
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxUnavailableNested<A> withNewMaxUnavailable() {
    return new io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluentImpl.MaxUnavailableNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return new io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluentImpl.MaxUnavailableNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxUnavailableNested<A> editMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable());
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): new io.fabric8.kubernetes.api.model.IntOrStringBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RollingUpdateDaemonSetFluentImpl that = (RollingUpdateDaemonSetFluentImpl) o;
    if (maxSurge != null ? !maxSurge.equals(that.maxSurge) :that.maxSurge != null) return false;
    if (maxUnavailable != null ? !maxUnavailable.equals(that.maxUnavailable) :that.maxUnavailable != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxSurge,  maxUnavailable,  additionalProperties,  super.hashCode());
  }
  public class MaxSurgeNestedImpl<N> extends io.fabric8.kubernetes.api.model.IntOrStringFluentImpl<io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxSurgeNested<N>> implements io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxSurgeNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MaxSurgeNestedImpl(io.fabric8.kubernetes.api.model.IntOrString item) {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this, item);
    }
    MaxSurgeNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this);
    }
    io.fabric8.kubernetes.api.model.IntOrStringBuilder builder;
    public N and() {
      return (N) RollingUpdateDaemonSetFluentImpl.this.withMaxSurge(builder.build());
    }
    public N endMaxSurge() {
      return and();
    }
    
  }
  public class MaxUnavailableNestedImpl<N> extends io.fabric8.kubernetes.api.model.IntOrStringFluentImpl<io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxUnavailableNested<N>> implements io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent.MaxUnavailableNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MaxUnavailableNestedImpl(io.fabric8.kubernetes.api.model.IntOrString item) {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this, item);
    }
    MaxUnavailableNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this);
    }
    io.fabric8.kubernetes.api.model.IntOrStringBuilder builder;
    public N and() {
      return (N) RollingUpdateDaemonSetFluentImpl.this.withMaxUnavailable(builder.build());
    }
    public N endMaxUnavailable() {
      return and();
    }
    
  }
  
}
